from __future__ import annotations
from pydantic import BaseModel
from typing import List
from datetime import datetime


class Model(BaseModel):
    requestid: str
    globalincidentid: str
    agencyid: int
    incidenttype: str
    resourceid: str
    tasktype: str
    locations: List[Location]
    timestamp: datetime
    comments: str
    status: str
    
    
class Location(BaseModel):
    latitude: float
    longitude: float


from __future__ import annotations

from pydantic import BaseModel
from typing import Optional


class DateObserved(BaseModel):
    type: str
    value: str


class Payload(BaseModel):
    victimid: str
    name: Optional[str] = None
    surname: Optional[str] = None
    dateofbirth: Optional[str] = None
    age: Optional[int] = None
    gender: Optional[str] = None
    encounterdatetime: Optional[str] = None
    triagestatus: Optional[str] = None
    totalgcs: Optional[int] = None
    dttid: Optional[str] = None
    currentdisposition: Optional[int] = None
    incidentid: Optional[str] = None
    contamination: Optional[bool] = None
    longitude: Optional[float] = None
    latitude: Optional[float] = None
    chiefcomplaint: Optional[str] = None
    chiefcomplaintname: Optional[str] = None
    pregnant: Optional[bool] = None
    gcseye: Optional[int] = None
    gcsverbal: Optional[int] = None
    gcsmotor: Optional[int] = None
    nickname: Optional[str] = None


class Model(BaseModel):
    id: str
    type: str
    dateObserved: DateObserved
    payload: Payload



from __future__ import annotations
from typing import List
from pydantic import BaseModel
from enum import Enum
from datetime import datetime

class triageColour(Enum):
    red = 1
    yellow = 2
    green = 3
    purple = 4

class vitals(BaseModel):
    heartRate: int
    oxygenSaturation: int
    diastolicBloodPressure: int
    systolicBloodPressure: int
    respiratoryRate: int
    temperature: int
    heartRateVariability: int
    GCS: int
    glucose: int
    treatment: str
    triageColour: triageColour
    date: datetime

class Model(BaseModel):
    victimID: str
    vitals: List[vitals]


from __future__ import annotations

from pydantic import BaseModel

from datetime import datetime
from typing import List, Optional


class DateObserved(BaseModel):
    type: str
    value: datetime


class Payload(BaseModel):
    victimid: str
    incidentid: str
    devicetype: str
    respiratoryrate: Optional[float] = -1
    systolicbloodpressure: Optional[float] = -1
    diastolicbloodpressure: Optional[float] = -1
    temperature: Optional[float] = -1
    pulserate: Optional[float] = -1
    heartratevariability: Optional[float] = -1
    pulseoxymetry: Optional[float] = -1
    skinmoisture: Optional[float] = -1
    encounterdatetime: datetime


class Model(BaseModel):
    id: str
    type: str
    dateObserved: DateObserved
    payload: Payload



from __future__ import annotations

from typing import Any, Dict, List, Optional

from pydantic import BaseModel, field_serializer
from datetime import datetime


class VitalPredictions(BaseModel):
    HR: float
    RR: float
    SBP: float
    DBP: float
    SPO2: float


class VitalEarlyWarningScore(BaseModel):
    HR: int
    RR: int
    SBP: int
    DBP: int
    SPO2: int

class ProcedureMessage(BaseModel):
    procedureName: str
    predictedInterventionTimestamp: datetime
    message: str
    
    @field_serializer('predictedInterventionTimestamp')
    def timestamp_serializer(self, predictedInterventionTimestamp: datetime, _info):
        return predictedInterventionTimestamp.isoformat().replace('+00:00', '') + 'Z'


class Prediction(BaseModel):
    timestamp: datetime
    earlyWarningScore: int
    vitalPredictions: VitalPredictions
    vitalEarlyWarningScore: VitalEarlyWarningScore
    shockIndex: float
    
    @field_serializer('timestamp')
    def timestamp_serializer(self, timestamp: datetime, _info):
        return timestamp.isoformat().replace('+00:00', '') + 'Z'


class Model(BaseModel):
    UUID: str
    timestamp: datetime
    requestId: str
    globalincidentid: str
    lastMeasurementTimestamp: datetime
    predictionTimestampId: str
    predictionTimeDeltaMinutes: int
    victimId: str
    procedureMessageCount: int
    procedureMessages: List[ProcedureMessage]
    predictions: List[Prediction]
    
    @field_serializer('timestamp')
    def serialize_timestamp(self, timestamp: datetime, _info):
        return timestamp.isoformat().replace('+00:00', '') + 'Z'
    
    @field_serializer('lastMeasurementTimestamp')
    def serialize_last_measurement_timestamp(self, lastMeasurementTimestamp: datetime, _info):
        return lastMeasurementTimestamp.isoformat().replace('+00:00', '') + 'Z'